"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRemoteImageUrl = exports.createEmbeddedImageUrl = exports.createLocalImageFileUrl = void 0;
const path = require("path");
const plantUmlEncoder = require("plantuml-encoder");
/**
 * Creates a URL to a local image file.
 * @param pageFilePath Path of the page that is referencing the image.
 * @param imageFilePath Path to the local image file.
 * @returns The URL to the local image file.
 */
function createLocalImageFileUrl(pageFilePath, imageFilePath) {
    const pageFileDir = path.dirname(pageFilePath);
    return path.relative(pageFileDir, imageFilePath);
}
exports.createLocalImageFileUrl = createLocalImageFileUrl;
/**
 * Creates a URL for an embedded image.
 * @param imageData The data of the image.
 * @param imageFormat The format of the image data.
 * @returns The URL for the embedded image.
 */
function createEmbeddedImageUrl(imageData, imageFormat) {
    const mimeType = imageFormat === "png" ? "image/png" : "image/svg+xml";
    return "data:" + mimeType + ";base64," + imageData.toString("base64");
}
exports.createEmbeddedImageUrl = createEmbeddedImageUrl;
/**
 * Creates a remote server URL that generates an image.
 * @param baseUrl The base URL for the image URL.
 * @param plantUmlCode The PlantUML code for the image.
 * @param imageFormat The format for the image.
 * @returns The remote server URL for the image.
 */
function createRemoteImageUrl(baseUrl, plantUmlCode, imageFormat) {
    const encodedPlantUml = plantUmlEncoder.encode(plantUmlCode);
    return baseUrl + "/plantuml/" + imageFormat + "/" + encodedPlantUml;
}
exports.createRemoteImageUrl = createRemoteImageUrl;
